==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.SkuArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * SKU for the resource.
 * @property capacity The SKU capacity.
 * @property family The SKU family.
 * @property model The SKU model.
 * @property name The SKU name.
 * @property size The SKU size.
 * @property tier The SKU tier.
 */
public data class SkuArgs(
    public val capacity: Output<Int>? = null,
    public val family: Output<String>? = null,
    public val model: Output<String>? = null,
    public val name: Output<String>? = null,
    public val size: Output<String>? = null,
    public val tier: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.resources.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.resources.inputs.SkuArgs =
        com.pulumi.azurenative.resources.inputs.SkuArgs.builder()
            .capacity(capacity?.applyValue({ args0 -> args0 }))
            .family(family?.applyValue({ args0 -> args0 }))
            .model(model?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .size(size?.applyValue({ args0 -> args0 }))
            .tier(tier?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var capacity: Output<Int>? = null

    private var family: Output<String>? = null

    private var model: Output<String>? = null

    private var name: Output<String>? = null

    private var size: Output<String>? = null

    private var tier: Output<String>? = null

    /**
     * @param value The SKU capacity.
     */
    @JvmName("aknrrsrjurxsyuml")
    public suspend fun capacity(`value`: Output<Int>) {
        this.capacity = value
    }

    /**
     * @param value The SKU family.
     */
    @JvmName("bnfctsgievqjbklo")
    public suspend fun family(`value`: Output<String>) {
        this.family = value
    }

    /**
     * @param value The SKU model.
     */
    @JvmName("psrnohvuoqnxwwrg")
    public suspend fun model(`value`: Output<String>) {
        this.model = value
    }

    /**
     * @param value The SKU name.
     */
    @JvmName("hgketnudkfwysdve")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The SKU size.
     */
    @JvmName("qwpxirqryoyvadga")
    public suspend fun size(`value`: Output<String>) {
        this.size = value
    }

    /**
     * @param value The SKU tier.
     */
    @JvmName("ygijpehxiiunjrsf")
    public suspend fun tier(`value`: Output<String>) {
        this.tier = value
    }

    /**
     * @param value The SKU capacity.
     */
    @JvmName("bpkdnvupwycmoyec")
    public suspend fun capacity(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.capacity = mapped
    }

    /**
     * @param value The SKU family.
     */
    @JvmName("ijlqluaphagbgvwe")
    public suspend fun family(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.family = mapped
    }

    /**
     * @param value The SKU model.
     */
    @JvmName("mguesnnfepglywoi")
    public suspend fun model(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.model = mapped
    }

    /**
     * @param value The SKU name.
     */
    @JvmName("wvjqjcfqqtefleqr")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The SKU size.
     */
    @JvmName("hxjhrxfxdogtantn")
    public suspend fun size(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.size = mapped
    }

    /**
     * @param value The SKU tier.
     */
    @JvmName("eeatdtwpwtgddvpi")
    public suspend fun tier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        capacity = capacity,
        family = family,
        model = model,
        name = name,
        size = size,
        tier = tier,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.SkuArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * SKU for the resource.
 * @property capacity The SKU capacity.
 * @property family The SKU family.
 * @property model The SKU model.
 * @property name The SKU name.
 * @property size The SKU size.
 * @property tier The SKU tier.
 */
public data class SkuArgs(
    public val capacity: Output<Int>? = null,
    public val family: Output<String>? = null,
    public val model: Output<String>? = null,
    public val name: Output<String>? = null,
    public val size: Output<String>? = null,
    public val tier: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.resources.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.resources.inputs.SkuArgs =
        com.pulumi.azurenative.resources.inputs.SkuArgs.builder()
            .capacity(capacity?.applyValue({ args0 -> args0 }))
            .family(family?.applyValue({ args0 -> args0 }))
            .model(model?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .size(size?.applyValue({ args0 -> args0 }))
            .tier(tier?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var capacity: Output<Int>? = null

    private var family: Output<String>? = null

    private var model: Output<String>? = null

    private var name: Output<String>? = null

    private var size: Output<String>? = null

    private var tier: Output<String>? = null

    /**
     * @param value The SKU capacity.
     */
    @JvmName("jdvkcsurirhqxfee")
    public suspend fun capacity(`value`: Output<Int>) {
        this.capacity = value
    }

    /**
     * @param value The SKU family.
     */
    @JvmName("ewsxnpahwnqmoorq")
    public suspend fun family(`value`: Output<String>) {
        this.family = value
    }

    /**
     * @param value The SKU model.
     */
    @JvmName("kgguunnjrouevrve")
    public suspend fun model(`value`: Output<String>) {
        this.model = value
    }

    /**
     * @param value The SKU name.
     */
    @JvmName("imsmnjrhnruscowy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The SKU size.
     */
    @JvmName("bxxdveoscynmimxp")
    public suspend fun size(`value`: Output<String>) {
        this.size = value
    }

    /**
     * @param value The SKU tier.
     */
    @JvmName("gkfagvpjqtxyafpu")
    public suspend fun tier(`value`: Output<String>) {
        this.tier = value
    }

    /**
     * @param value The SKU capacity.
     */
    @JvmName("nmepppoljikhjpae")
    public suspend fun capacity(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.capacity = mapped
    }

    /**
     * @param value The SKU family.
     */
    @JvmName("dnaqheyukmgotlsr")
    public suspend fun family(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.family = mapped
    }

    /**
     * @param value The SKU model.
     */
    @JvmName("yhyxnuxlrvjbdkey")
    public suspend fun model(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.model = mapped
    }

    /**
     * @param value The SKU name.
     */
    @JvmName("pamrncqcdmkblwhj")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The SKU size.
     */
    @JvmName("haxknxnvajsuresr")
    public suspend fun size(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.size = mapped
    }

    /**
     * @param value The SKU tier.
     */
    @JvmName("clpsxoiprtvlhbwb")
    public suspend fun tier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        capacity = capacity,
        family = family,
        model = model,
        name = name,
        size = size,
        tier = tier,
    )
}
